@@ -19,14 +19,17 @@
 */
 #include "common.h"
 #include "pid.h"
+#include "utils.h"
 #include <string.h>
 #include <sys/types.h>
 #include <pwd.h>
 #include <sys/ioctl.h>
 #include <dirent.h>
-       
+#include <limits.h>
+
 #define PIDS_BUFLEN 4096
 Process *pids = 0;
+ProcessData *pids_data = 0;
 int pids_first = 0;
 int pids_last = 0;
 int max_pids = 32769;
@@ -47,7 +50,7 @@ void pid_getmem(unsigned pid, unsigned *rss, unsigned *shared) {
 		return;
 	}
 	free(file);
-	
+
 	unsigned a, b, c;
 	if (3 != fscanf(fp, "%u %u %u", &a, &b, &c)) {
 		fclose(fp);
@@ -72,7 +75,7 @@ void pid_get_cpu_time(unsigned pid, unsigned *utime, unsigned *stime) {
 		return;
 	}
 	free(file);
-	
+
 	char line[PIDS_BUFLEN];
 	if (fgets(line, PIDS_BUFLEN - 1, fp)) {
 		char *ptr = line;
@@ -89,7 +92,7 @@ void pid_get_cpu_time(unsigned pid, unsigned *utime, unsigned *stime) {
 			goto myexit;
 	}
 
-myexit:	
+myexit:
 	fclose(fp);
 }
 
@@ -106,7 +109,7 @@ unsigned long long pid_get_start_time(unsigned pid) {
 		return 0;
 	}
 	free(file);
-	
+
 	char line[PIDS_BUFLEN];
 	unsigned long long retval = 0;
 	if (fgets(line, PIDS_BUFLEN - 1, fp)) {
@@ -123,7 +126,7 @@ unsigned long long pid_get_start_time(unsigned pid) {
 		if (1 != sscanf(ptr, "%llu", &retval))
 			goto myexit;
 	}
-	
+
 myexit:
 	fclose(fp);
 	return retval;
@@ -138,7 +141,7 @@ char *pid_get_user_name(uid_t uid) {
 
 uid_t pid_get_uid(pid_t pid) {
 	uid_t rv = 0;
-	
+
 	// open stat file
 	char *file;
 	if (asprintf(&file, "/proc/%u/status", pid) == -1) {
@@ -161,12 +164,12 @@ uid_t pid_get_uid(pid_t pid) {
 			}
 			if (*ptr == '\0')
 				goto doexit;
-				
+
 			rv = atoi(ptr);
 			break; // break regardless!
 		}
 	}
-doexit:	
+doexit:
 	fclose(fp);
 	free(file);
 	return rv;
@@ -177,9 +180,8 @@ doexit:
 
 // mon_pid: pid of sandbox to be monitored, 0 if all sandboxes are included
 void pid_read(pid_t mon_pid) {
-	pids_first = 0;
-	pids_last = 0;
-	if (pids == NULL) {	
+//timetrace_start();
+	if (pids == NULL) {
 		FILE *fp = fopen("/proc/sys/kernel/pid_max", "r");
 		if (fp) {
 			int val;
@@ -189,12 +191,19 @@ void pid_read(pid_t mon_pid) {
 			}
 			fclose(fp);
 		}
-		pids = (Process *) malloc(sizeof(Process) * max_pids);
-		if (pids == NULL) 
+		pids = (Process *) malloc(sizeof(Process) * max_pids + 1);
+		if (pids == NULL)
 			errExit("malloc");
+		memset(pids, 0, sizeof(Process) * max_pids);
+		pids_data = (ProcessData *) malloc(sizeof(ProcessData) * max_pids + 1);
+		if (pids == NULL)
+			errExit("malloc");
+		memset(pids_data, 0, sizeof(Process) * max_pids);
 	}
 
-	memset(pids, 0, sizeof(Process) * max_pids);
+	memset(pids + pids_first, 0, sizeof(Process) * (pids_last - pids_first + 1));
+	pids_first = 0;
+	pids_last = 0;
 	pid_t mypid = getpid();
 
 	DIR *dir;
@@ -206,18 +215,19 @@ void pid_read(pid_t mon_pid) {
 			exit(1);
 		}
 	}
-	
+
 	pid_t child = -1;
 	struct dirent *entry;
 	char *end;
 	while (child < 0 && (entry = readdir(dir))) {
 		pid_t pid = strtol(entry->d_name, &end, 10);
 		pid %= max_pids;
+		pids_last = pid;
 		if (end == entry->d_name || *end)
 			continue;
 		if (pid == mypid)
 			continue;
-		
+
 		// open stat file
 		char *file;
 		if (asprintf(&file, "/proc/%u/status", pid) == -1) {
@@ -230,6 +240,8 @@ void pid_read(pid_t mon_pid) {
 			continue;
 		}
 
+		memset(&pids_data[pid], 0, sizeof(ProcessData));
+
 		// look for firejail executable name
 		char buf[PIDS_BUFLEN];
 		while (fgets(buf, PIDS_BUFLEN - 1, fp)) {
@@ -245,20 +257,19 @@ void pid_read(pid_t mon_pid) {
 
 				if ((strncmp(ptr, "firejail", 8) == 0) && (mon_pid == 0 || mon_pid == pid)) {
 					if (pid_proc_cmdline_x11_xpra_xephyr(pid))
-						pids[pid].level = -1;
+						pids[pid].level = 0;
 					else {
 						pids[pid].level = 1;
 						if (pids_first == 0)
 							pids_first = pid;
-						pids_last = pid;
 					}
 				}
 				else
-					pids[pid].level = -1;
+					pids[pid].level = 0;
 			}
 			if (strncmp(buf, "State:", 6) == 0) {
 				if (strstr(buf, "(zombie)"))
-					pids[pid].zombie = 1;
+					pids[pid].level = 0;
 			}
 			else if (strncmp(buf, "PPid:", 5) == 0) {
 				char *ptr = buf + 5;
@@ -271,10 +282,11 @@ void pid_read(pid_t mon_pid) {
 				}
 				unsigned parent = atoi(ptr);
 				parent %= max_pids;
-				if (pids[parent].level > 0) {
-					pids[pid].level = pids[parent].level + 1;
-					pids[pid].parent = parent;
-				}
+				pids_data[pid].parent = parent;
+				if (pids[parent].level > 0)
+					pids[pid].level = (pids[parent].level == UCHAR_MAX)? UCHAR_MAX:  pids[parent].level + 1;
+//if (pids[pid].level)
+//printf("pid %d level %u  parent %d\n", pid, pids[pid].level, pids_data[pid].parent);
 			}
 			else if (strncmp(buf, "Uid:", 4) == 0) {
 				if (pids[pid].level > 0) {
@@ -286,7 +298,7 @@ void pid_read(pid_t mon_pid) {
 						fprintf(stderr, "Error: cannot read /proc file\n");
 						exit(1);
 					}
-					pids[pid].uid = atoi(ptr);
+					pids_data[pid].uid = atoi(ptr);
 				}
 				break;
 			}
@@ -300,7 +312,7 @@ void pid_read(pid_t mon_pid) {
 // return 1 if error
 int name2pid(const char *name, pid_t *pid) {
 	pid_t parent = getpid();
-	
+
 	DIR *dir;
 	if (!(dir = opendir("/proc"))) {
 		// sleep 2 seconds and try again
@@ -310,7 +322,7 @@ int name2pid(const char *name, pid_t *pid) {
 			exit(1);
 		}
 	}
-	
+
 	struct dirent *entry;
 	char *end;
 	while ((entry = readdir(dir))) {
@@ -333,7 +345,7 @@ int name2pid(const char *name, pid_t *pid) {
 			}
 			free(comm);
 		}
-		
+
 		char *cmd = pid_proc_cmdline(newpid);
 		if (cmd) {
 			// mark the end of the name
@@ -438,20 +450,21 @@ char *pid_proc_cmdline(const pid_t pid) {
 
 // recursivity!!!
 void pid_get_cpu_sandbox(unsigned pid, unsigned *utime, unsigned *stime) {
+//printf("call %d, last %d\n", pid, pids_last);
 	if (pids[pid].level == 1) {
 		*utime = 0;
 		*stime = 0;
 	}
-	
+
 	unsigned utmp = 0;
 	unsigned stmp = 0;
 	pid_get_cpu_time(pid, &utmp, &stmp);
 	*utime += utmp;
 	*stime += stmp;
-	
+
 	int i;
-	for (i = pid + 1; i < max_pids; i++) {
-		if (pids[i].parent == (int) pid)
+	for (i = pid + 1; i < (pids_last + 1); i++) {
+		if (pids_data[i].parent == (int) pid)
 			pid_get_cpu_sandbox(i, utime, stime);
 	}
 }
@@ -461,12 +474,12 @@ void pid_get_mem_sandbox(unsigned pid, unsigned *rss, unsigned *shared) {
 		*rss = 0;
 		*shared = 0;
 	}
-	
+
 	pid_getmem(pid, rss, shared);
-	
+
 	int i;
-	for (i = pid + 1; i < max_pids; i++) {
-		if (pids[i].parent == (int) pid)
+	for (i = pid + 1; i < (pids_last + 1); i++) {
+		if (pids_data[i].parent == (int) pid)
 			pid_get_mem_sandbox(i, rss, shared);
 	}
 }
@@ -475,14 +488,17 @@ void pid_get_mem_sandbox(unsigned pid, unsigned *rss, unsigned *shared) {
 void pid_get_netstats_sandbox(int parent, unsigned long long *rx, unsigned long long *tx) {
 	*rx = 0;
 	*tx = 0;
-	
+
 	// find the first child
 	int child = -1;
-	for (child = parent + 1; child < max_pids; child++) {
-		if (pids[child].parent == parent)
-			break;
+	if (parent == 1)
+		child = 1;
+	else {
+		for (child = parent + 1; child < (pids_last + 1); child++) {
+			if (pids_data[child].parent == parent)
+				break;
+		}
 	}
-
 	if (child == -1)
 		return;
 
@@ -496,26 +512,26 @@ void pid_get_netstats_sandbox(int parent, unsigned long long *rx, unsigned long
 		free(fname);
 		return;
 	}
-	
+
 	char buf[MAXBUF];
 	while (fgets(buf, MAXBUF, fp)) {
 		if (strncmp(buf, "Inter", 5) == 0)
 			continue;
 		if (strncmp(buf, " face", 5) == 0)
 			continue;
-		
+
 		char *ptr = buf;
 		while (*ptr != '\0' && *ptr != ':') {
 			ptr++;
 		}
-		
+
 		if (*ptr == '\0') {
 			fclose(fp);
 			free(fname);
 			return;
 		}
 		ptr++;
-		
+
 		long long unsigned rxval;
 		long long unsigned txval;
 		unsigned a, b, c, d, e, f, g;
@@ -580,7 +596,7 @@ static int pid_proc_cmdline_x11_xpra_xephyr(const pid_t pid) {
 			break;
 		if (strncmp(arg, "--", 2) != 0)
 			break;
-			
+
 		if (strcmp(arg, "--x11=xorg") == 0)
 			return 0;
 
@@ -593,4 +609,37 @@ static int pid_proc_cmdline_x11_xpra_xephyr(const pid_t pid) {
 }
 
 
+// dbus proxy path used by firejail and firemon
+#define XDG_DBUS_PROXY_PATH "/usr/bin/xdg-dbus-proxy"
+int pid_find_child(int id) {
+	int i;
+	int first_child = -1;
+	// find the first child
+	for (i = 0; i < max_pids && first_child == -1; i++) {
+		if (pids[i].level == 2 && pids_data[i].parent == id) {
+			// skip /usr/bin/xdg-dbus-proxy (started by firejail for dbus filtering)
+			char *cmdline = pid_proc_cmdline(i);
+			if (strncmp(cmdline, XDG_DBUS_PROXY_PATH, strlen(XDG_DBUS_PROXY_PATH)) == 0) {
+				free(cmdline);
+				continue;
+			}
+			free(cmdline);
+			first_child = i;
+			break;
+		}
+	}
+
+	if (first_child == -1)
+		return -1;
+
+	// find the second-level child
+	for (i = 0; i < max_pids; i++) {
+		if (pids[i].level == 3 && pids_data[i].parent == first_child)
+			return i;
+	}
+
+	// if a second child is not found, return the first child pid
+	// this happens for processes sandboxed with --join
+	return first_child;
+}
 
