@@ -29,7 +29,7 @@ public:
 	static const int MAXCYCLE = 60;
 	static const int G1HCYCLE_DELTA = 60;	// transition from 1min to 1h
 	static const int G12HCYCLE_DELTA = 12;	// transition from 1h to 12h
-	DbStorage data_4min_[MAXCYCLE];
+	DbStorage data_1min_[MAXCYCLE];
 	DbStorage data_1h_[MAXCYCLE];
 	DbStorage data_12h_[MAXCYCLE];
 
@@ -53,11 +53,17 @@ public:
 	pid_t getPid() {
 		return pid_;
 	}
-	bool networkDisabled() {
-		return network_disabled_;
+	bool netNamespace() {
+		return netnamespace_;
 	}
-	void setNetworkDisabled(bool val) {
-		network_disabled_ = val;
+	void setNetNamespace(bool val) {
+		netnamespace_ = val;
+	}
+	bool netNone() {
+		return netnone_;
+	}
+	void setNetNone(bool val) {
+		netnone_ = val;
 	}
 	uid_t getUid() {
 		return uid_;
@@ -65,22 +71,23 @@ public:
 	void setUid(uid_t val) {
 		uid_ = val;
 	}
-	
+
 	bool isConfigured() {
 		return configured_;
 	}
-	
+
 	void setConfigured() {
 		configured_ = true;
 	}
 
-private:	
+private:
 	DbPid *next_;
 	pid_t pid_;
 	char *cmd_;
-	bool network_disabled_;
+	bool netnamespace_;
+	bool netnone_;
 	uid_t uid_;
 	bool configured_;
 };
 
-#endif
\ No newline at end of file
+#endif
