@@ -43,12 +43,12 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 
 	assert(cycle < DbPid::MAXCYCLE);
 	int maxcycle = DbPid::MAXCYCLE;
-	int i;	
+	int i;
 	int j;
-	
+
 	// set pixmap
 #define TOPMARGIN 20
-#define RIGHTMARGIN 60	
+#define RIGHTMARGIN 60
 	QPixmap *pixmap = new QPixmap((maxcycle - 1) * 4 + RIGHTMARGIN, TOPMARGIN + 100 + 30);
 	QPainter *paint = new QPainter(pixmap);
 	paint->fillRect(0, 0, (maxcycle - 1) * 4 + 100, TOPMARGIN + 100 + 30, Qt::white);
@@ -61,20 +61,20 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 	paint->drawLine((maxcycle - 1) * 1, TOPMARGIN, (maxcycle - 1) * 1, TOPMARGIN + 100);
 	paint->drawLine((maxcycle - 1) * 2, TOPMARGIN, (maxcycle - 1) * 2, TOPMARGIN + 100);
 	paint->drawLine((maxcycle - 1) * 3, TOPMARGIN, (maxcycle - 1) * 3, TOPMARGIN + 100);
-	
+
 	// extract maximum value
 	float maxval = 0;
 	for (i = 0; i < maxcycle; i++) {
 		float val;
-		if (gt == GRAPH_4MIN)
-			val  = dbpid->data_4min_[i].get(id);
+		if (gt == GRAPH_1MIN)
+			val  = dbpid->data_1min_[i].get(id);
 		else if (gt == GRAPH_1H)
 			val  = dbpid->data_1h_[i].get(id);
 		else if (gt == GRAPH_12H)
 			val  = dbpid->data_12h_[i].get(id);
 		else
 			assert(0);
-			
+
 		if (val > maxval)
 			maxval = val;
 	}
@@ -123,15 +123,15 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 	paint->setPen(Qt::red);
 	for (i = 0, j = cycle + 1; i < maxcycle - 1; i++) {
 		float y1;
-		if (gt == GRAPH_4MIN)
-			y1 = dbpid->data_4min_[j].get(id);
+		if (gt == GRAPH_1MIN)
+			y1 = dbpid->data_1min_[j].get(id);
 		else if (gt == GRAPH_1H)
 			y1 = dbpid->data_1h_[j].get(id);
 		else if (gt == GRAPH_12H)
 			y1 = dbpid->data_12h_[j].get(id);
 		else
 			assert(0);
-			
+
 		y1 = (y1 / maxval) * 100;
 		y1 = 100 - y1 + TOPMARGIN;
 		j++;
@@ -139,15 +139,15 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 			j = 0;
 
 		float y2;
-		if (gt == GRAPH_4MIN)
-			y2 = dbpid->data_4min_[j].get(id);
+		if (gt == GRAPH_1MIN)
+			y2 = dbpid->data_1min_[j].get(id);
 		else if (gt == GRAPH_1H)
 			y2 = dbpid->data_1h_[j].get(id);
 		else if (gt == GRAPH_12H)
 			y2 = dbpid->data_12h_[j].get(id);
 		else
 			assert(0);
-			
+
 		y2 = (y2 / maxval) * 100;
 		y2 = 100 - y2 + TOPMARGIN;
 		paint->drawLine(i * 4, (int) y1, (i + 1) * 4, (int) y2);
@@ -168,7 +168,7 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 		paint->drawText(0 + 2, TOPMARGIN + 100 + 15, QString("(minutes)"));
 	else
 		paint->drawText(0 + 2, TOPMARGIN + 100 + 15, QString("(seconds)"));
-	if (gt == GRAPH_4MIN) {
+	if (gt == GRAPH_1MIN) {
 		paint->drawText((maxcycle - 1) * 2 - 5, TOPMARGIN + 100 + 15, QString("-30"));
 		paint->drawText((maxcycle - 1) * 3 - 5, TOPMARGIN + 100 + 15, QString("-15"));
 	}
@@ -182,12 +182,12 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 	}
 	else
 		assert(0);
-	
-	
+
+
 	// title
 	paint->setPen(Qt::black);
 	paint->drawText(0 + 2, TOPMARGIN - 2, QString(id_label[id]));
-	
+
 	// generate image
 	QBuffer buffer(&byteArray[id]);
 	pixmap->save(&buffer, "PNG");
@@ -197,19 +197,3 @@ QString graph(int id, DbPid *dbpid, int cycle, GraphType gt) {
 	delete pixmap;
 	return url;
 }
-// qt bug reported at https://bugreports.qt.io/browse/QTBUG-43270:
-// A html source containing an embedded image read into QTextBrowser creates an error message 
-// "QFSFileEngine::open: No file name specified", even though the image is parsed and rendered fine.
-
-//http://stackoverflow.com/questions/6598554/is-there-any-way-to-insert-qpixmap-object-in-html
-
-#if 0
-    QString html;
-     
-    QImage img("c:\\temp\\sample.png"); // todo: generate image in memory
-    myTextEdit->document()->addResource(QTextDocument::ImageResource, QUrl("sample.png" ), img);
-     
-    html.append("<p><img src=\":sample.png\"></p>");
-     
-    myTextEdit->setHtml(html);
-#endif
